@@ -148,10 +148,22 @@ public:
      **/
     Q_INVOKABLE void requestResize(int row);
 
+#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 52)
     /**
      * Request the window at this model row index be moved to this virtual desktop.
+     *
+     * @deprecated Since 5.52; starting from 5.90, use requestEnterVirtualDesktop(int row, const QString &id) instead.
      **/
+    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 52, "Starting from 5.90 use PlasmaWindowModel::requestEnterVirtualDesktop(int row, const QString &id) instead.")
     Q_INVOKABLE void requestVirtualDesktop(int row, quint32 desktop);
+#endif
+
+    /**
+     * Request the window at the model index @p row to be moved to the virtual desktop @p id.
+     *
+     * @since 5.90
+     **/
+    Q_INVOKABLE void requestEnterVirtualDesktop(int row, const QString &id);
 
     /**
      * Requests the window at this model row index have its keep above state toggled.
