@@ -57,7 +57,7 @@ class KWAYLANDCLIENT_EXPORT Shell : public QObject
     Q_OBJECT
 public:
     explicit Shell(QObject *parent = nullptr);
-    virtual ~Shell();
+    ~Shell() override;
 
     /**
      * @returns @c true if managing a wl_shell.
@@ -125,8 +125,8 @@ public:
      **/
     ShellSurface *createSurface(Surface *surface, QObject *parent = nullptr);
 
-    operator wl_shell*();
-    operator wl_shell*() const;
+    operator wl_shell *();
+    operator wl_shell *() const;
 
 Q_SIGNALS:
     /**
@@ -172,7 +172,7 @@ class KWAYLANDCLIENT_EXPORT ShellSurface : public QObject
     Q_PROPERTY(QSize size READ size WRITE setSize NOTIFY sizeChanged)
 public:
     explicit ShellSurface(QObject *parent);
-    virtual ~ShellSurface();
+    ~ShellSurface() override;
 
     /**
      * Releases the wl_shell_surface interface.
@@ -220,7 +220,7 @@ public:
      **/
     enum class TransientFlag {
         Default = 0x0, ///< Default: transient surface accepts keyboard focus
-        NoFocus = 0x1 ///< Transient surface does not accept keyboard focus
+        NoFocus = 0x1, ///< Transient surface does not accept keyboard focus
     };
     Q_DECLARE_FLAGS(TransientFlags, TransientFlag)
     /**
@@ -251,7 +251,8 @@ public:
      * @param flags The flags for the transient
      * @since 5.33
      **/
-    void setTransientPopup(Surface *parent, Seat *grabbedSeat, quint32 grabSerial, const QPoint &offset = QPoint(), TransientFlags flags = TransientFlag::Default);
+    void
+    setTransientPopup(Surface *parent, Seat *grabbedSeat, quint32 grabSerial, const QPoint &offset = QPoint(), TransientFlags flags = TransientFlag::Default);
 
     bool isValid() const;
 
@@ -324,8 +325,8 @@ public:
      **/
     static ShellSurface *get(wl_shell_surface *native);
 
-    operator wl_shell_surface*();
-    operator wl_shell_surface*() const;
+    operator wl_shell_surface *();
+    operator wl_shell_surface *() const;
 
 Q_SIGNALS:
     /**
