@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2015  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "shadow_interface.h"
 #include "buffer_interface.h"
 #include "display.h"
@@ -31,7 +17,6 @@ namespace KWayland
 {
 namespace Server
 {
-
 class ShadowManagerInterface::Private : public Global::Private
 {
 public:
@@ -45,8 +30,9 @@ private:
     static void unsetCallback(wl_client *client, wl_resource *resource, wl_resource *surface);
     static void destroyCallback(wl_client *client, wl_resource *resource);
     static void unbind(wl_resource *resource);
-    static Private *cast(wl_resource *r) {
-        return reinterpret_cast<Private*>(wl_resource_get_user_data(r));
+    static Private *cast(wl_resource *r)
+    {
+        return reinterpret_cast<Private *>(wl_resource_get_user_data(r));
     }
 
     ShadowManagerInterface *q;
@@ -57,11 +43,7 @@ private:
 const quint32 ShadowManagerInterface::Private::s_version = 2;
 
 #ifndef K_DOXYGEN
-const struct org_kde_kwin_shadow_manager_interface ShadowManagerInterface::Private::s_interface = {
-    createCallback,
-    unsetCallback,
-    destroyCallback
-};
+const struct org_kde_kwin_shadow_manager_interface ShadowManagerInterface::Private::s_interface = {createCallback, unsetCallback, destroyCallback};
 #endif
 
 ShadowManagerInterface::Private::Private(ShadowManagerInterface *q, Display *d)
@@ -138,7 +120,7 @@ class ShadowInterface::Private : public Resource::Private
 {
 public:
     Private(ShadowInterface *q, ShadowManagerInterface *c, wl_resource *parentResource);
-    ~Private();
+    ~Private() override;
 
     struct State {
         enum Flags {
@@ -151,7 +133,7 @@ public:
             BottomRightBuffer = 1 << 5,
             BottomBuffer = 1 << 6,
             BottomLeftBuffer = 1 << 7,
-            Offset = 1 << 8
+            Offset = 1 << 8,
         };
         BufferInterface *left = nullptr;
         BufferInterface *topLeft = nullptr;
@@ -162,7 +144,7 @@ public:
         BufferInterface *bottom = nullptr;
         BufferInterface *bottomLeft = nullptr;
         QMarginsF offset;
-        Flags flags  = Flags::None;
+        Flags flags = Flags::None;
     };
     State current;
     State pending;
@@ -170,7 +152,8 @@ public:
 private:
     void commit();
     void attach(State::Flags flag, wl_resource *buffer);
-    ShadowInterface *q_func() {
+    ShadowInterface *q_func()
+    {
         return reinterpret_cast<ShadowInterface *>(q);
     }
 
@@ -192,22 +175,20 @@ private:
 };
 
 #ifndef K_DOXYGEN
-const struct org_kde_kwin_shadow_interface ShadowInterface::Private::s_interface = {
-    commitCallback,
-    attachLeftCallback,
-    attachTopLeftCallback,
-    attachTopCallback,
-    attachTopRightCallback,
-    attachRightCallback,
-    attachBottomRightCallback,
-    attachBottomCallback,
-    attachBottomLeftCallback,
-    offsetLeftCallback,
-    offsetTopCallback,
-    offsetRightCallback,
-    offsetBottomCallback,
-    resourceDestroyedCallback
-};
+const struct org_kde_kwin_shadow_interface ShadowInterface::Private::s_interface = {commitCallback,
+                                                                                    attachLeftCallback,
+                                                                                    attachTopLeftCallback,
+                                                                                    attachTopCallback,
+                                                                                    attachTopRightCallback,
+                                                                                    attachRightCallback,
+                                                                                    attachBottomRightCallback,
+                                                                                    attachBottomCallback,
+                                                                                    attachBottomLeftCallback,
+                                                                                    offsetLeftCallback,
+                                                                                    offsetTopCallback,
+                                                                                    offsetRightCallback,
+                                                                                    offsetBottomCallback,
+                                                                                    resourceDestroyedCallback};
 #endif
 
 void ShadowInterface::Private::commitCallback(wl_client *client, wl_resource *resource)
@@ -218,6 +199,7 @@ void ShadowInterface::Private::commitCallback(wl_client *client, wl_resource *re
 
 void ShadowInterface::Private::commit()
 {
+// clang-format off
 #define BUFFER( __FLAG__, __PART__ ) \
     if (pending.flags & State::Flags::__FLAG__##Buffer) { \
         if (current.__PART__) { \
@@ -390,6 +372,7 @@ BufferInterface *ShadowInterface::__PART__() const \
     Q_D(); \
     return d->current.__PART__; \
 }
+// clang-format on
 
 BUFFER(left)
 BUFFER(topLeft)
@@ -402,7 +385,7 @@ BUFFER(bottomLeft)
 
 ShadowInterface::Private *ShadowInterface::d_func() const
 {
-    return reinterpret_cast<Private*>(d.data());
+    return reinterpret_cast<Private *>(d.data());
 }
 
 }
