@@ -15,7 +15,6 @@ namespace KWayland
 {
 namespace Server
 {
-
 class Display;
 
 /**
@@ -25,7 +24,7 @@ class KWAYLANDSERVER_EXPORT SlideManagerInterface : public Global
 {
     Q_OBJECT
 public:
-    virtual ~SlideManagerInterface();
+    ~SlideManagerInterface() override;
 
 private:
     explicit SlideManagerInterface(Display *display, QObject *parent = nullptr);
@@ -44,10 +43,10 @@ public:
         Left = 0, /**< Slide from the left edge of the screen */
         Top, /**< Slide from the top edge of the screen */
         Right, /**< Slide from the bottom edge of the screen */
-        Bottom /**< Slide from the bottom edge of the screen */
+        Bottom, /**< Slide from the bottom edge of the screen */
     };
 
-    virtual ~SlideInterface();
+    ~SlideInterface() override;
 
     /**
      * @returns the location the window will be slided from
@@ -68,7 +67,6 @@ private:
     Private *d_func() const;
 };
 
-
 }
 }
 
